@@ -118,6 +118,17 @@ sub ACTION_build
           # this is probably not necessary...
           eval { chmod 0755, $config_site };
           $ENV{CONFIG_SITE} = $config_site;
+          
+          if($^O eq 'MSWin32')
+          {
+            my $dir = _catdir($prefix, 'lib');
+            mkdir $dir;
+            my $la = _catfile($dir, 'libbz2.la');
+            open my $fh, '>', $la;
+            binmode $fh;
+            print $fh _bz2_la_file($prefix);
+            close $fh;
+          }
         }
       }
     
@@ -157,4 +168,60 @@ sub ACTION_build
   $self->SUPER::ACTION_build(@_);
 }
 
+my $bz2_la_template;
+sub _bz2_la_file
+{
+  my($prefix) = @_;
+  unless(defined $bz2_la_template)
+  {
+    $bz2_la_template = do { local $/; <DATA> };
+  }
+  my $bz2_la = $bz2_la_template;
+  $bz2_la =~ s{##PREFIX##}{$prefix}g;
+  $bz2_la;
+}
+
 1;
+
+__DATA__
+# libbz2.la - a libtool library file
+# Generated by libtool (GNU libtool) 2.4.2 Debian-2.4.2-1.1
+#
+# Please DO NOT delete this file!
+# It is necessary for linking the library.
+
+# The name that we can dlopen(3).
+dlname='../bin/bzip2.dll'
+
+# Names of this library.
+library_names='../dll/libbz2.dll.a'
+
+# The name of the static archive.
+old_library='libbz2.a'
+
+# Linker flags that can not go in dependency_libs.
+inherited_linker_flags=''
+
+# Libraries that this one depends upon.
+dependency_libs=''
+
+# Names of additional weak libraries provided by this library
+weak_library_names=''
+
+# Version information for libbz2.
+current=14
+age=1
+revision=2
+
+# Is this an already installed library?
+installed=yes
+
+# Should we warn about portability when linking against -modules?
+shouldnotlink=no
+
+# Files to dlopen/dlpreopen
+dlopen=''
+dlpreopen=''
+
+# Directory that this library needs to be installed in:
+libdir='##PREFIX##/lib'
